within ;
model SupermarketRefrigerationSystem_CO2_20190524
  "Supermarket Refrigeration System CO2"

  model CompressorController
    extends Modelica.Blocks.Interfaces.BlockIcon;

    Modelica.Blocks.Interfaces.RealInput u annotation (Placement(transformation(
            extent={{-140,-20},{-100,20}}, rotation=0)));
    Modelica.Blocks.Interfaces.RealOutput n1 annotation (Placement(
          transformation(extent={{100,50},{120,70}}, rotation=0)));
    Modelica.Blocks.Interfaces.RealOutput n2 annotation (Placement(
          transformation(extent={{100,-70},{120,-50}}, rotation=0)));

    parameter Real delta_u=0.01 "Hysteresis";

    parameter Real n1_max "Maximum speed of compressor 1";
    parameter Real n2_max "Maximum speed of compressor 2";
    parameter Real n2_min=0.0 "Minimum speed of compressor 2";

    Boolean compressorTwoIsActive;

  algorithm
    when u > (1 + delta_u/2) then
      compressorTwoIsActive := true;
    end when;

    when u < (1 - delta_u/2) then
      compressorTwoIsActive := false;
    end when;

  equation
    if compressorTwoIsActive then
      n1 = max((u - 1)*n1_max, n2_min);
      n2 = n2_max;
    else
      n1 = max(min(u*n1_max, n1_max), n2_min);
      n2 = 0.0;
    end if;

    annotation (
      Icon(graphics),
      Diagram(graphics));
  end CompressorController;

  TIL.VLEFluidComponents.Compressors.EffCompressor MPComp_FI(
    nFixed=50,
    use_mechanicalPort=true,
    displacement=7.31e-5)               annotation (Placement(transformation(
          extent={{142,-108},{158,-92}},rotation=0)));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_LP(
    useTimeConstant=true,
    tau=0.1,
    initialSensorValue=1100000) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={100,-136})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs4(
      use_nInput=true, nFixed=45) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={170,-100})));
  TIL.OtherComponents.Controllers.PIController PI_LPComp(
    yMax=2,
    yMin=0,
    Ti=10,
    k=0.005,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    yInitial=0.73)       annotation (Placement(transformation(extent={{226,-112},
            {214,-100}},rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_LP_Comp(y=11e5) annotation (
      Placement(transformation(
        origin={250,-106},
        extent={{10,-10},{-10,10}},
        rotation=0)));
  TIL.VLEFluidComponents.Compressors.EffCompressor MPComp_noFI(
    nFixed=50,
    use_mechanicalPort=true,
    displacement=7.31e-5)               annotation (Placement(transformation(
          extent={{82,-108},{98,-92}},    rotation=0)));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs5(
      use_nInput=true, nFixed=50) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={110,-100})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_MPCompOut(
    volume=1e-2,
    pressureStateID=9,
    hInitial=446e3) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={118,-82})));
  CompressorController compressorControllerMP(
    n1_max=70,
    n2_max=50,
    n2_min=0) annotation (Placement(transformation(extent={{200,-116},{180,-96}},
          rotation=0)));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_4(
                                            pressureStateID=4, pInitial(
        displayUnit="Pa") = 34.566e5)                          annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=90,
        origin={-260,30})));
  TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.CrossFlowHX MTCabinet(
    redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
    nCells=10,
    vleFluidType=sim.vleFluidType1,
    initVLEFluid="linearEnthalpyDistribution",
    m_flowMoistAirStart=1,
    redeclare model FinSidePressureDropModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
    alphaAInitialVLEFluid=2980,
    pressureStateID=5,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    hxGeometry(
      finnedTubeLength=2,
      nTubeSideParallelHydraulicFlows=5,
      nSerialTubes=40,
      nParallelTubes=40),
    redeclare model TubeSidePressureDropModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model TubeSideHeatTransferModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
        (constantAlpha=6000),
    redeclare model FinSideHeatTransferModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
        (constantAlpha=100),
    hInitialVLEFluid_Cell1=199e3,
    hInitialVLEFluid_CellN=446e3,
    TInitialWall(displayUnit="K") = 273.15 - 3,
    pVLEFluidStart=2800000) annotation (Placement(transformation(
        origin={-60,-20},
        extent={{14,-14},{-14,14}},
        rotation=180)));

  TIL.VLEFluidComponents.Valves.OrificeValve MTValve(effectiveFlowAreaFixed=
        0.2e-5, use_effectiveFlowAreaInput=true) annotation (Placement(
        transformation(
        extent={{-8.0,-4.0},{8.0,4.0}},
        rotation=0,
        origin={-210,-20})));
  TIL.GasComponents.Volumes.Volume volume_MTCabinet(
    m_flowStart=5,
    volume=185,
    TInitial=276.15) annotation (Placement(transformation(
        extent={{-4.0,-8.0},{4.0,8.0}},
        rotation=90,
        origin={-64,-80})));
  TIL.OtherComponents.Thermal.HeatBoundary heatBoundary_MTCabinet(
    TFixed(displayUnit="K") = 273.15 + 21,
    boundaryType="Q_flow",
    use_heatFlowRateInput=false,
    Q_flowFixed(displayUnit="kW") = -65000) annotation (Placement(
        transformation(
        extent={{-4.0,-6.0},{4.0,6.0}},
        rotation=0,
        origin={-80,-80})));
  TIL.OtherComponents.Controllers.PIController PI_MTValve(
    yMin=0.2e-12,
    yMax=0.1e-3,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    yInitial=7.70407e-6,
    k=5e-8,
    Ti=100)    annotation (Placement(transformation(
        origin={-130,30},
        extent={{-6,6},{6,-6}},
        rotation=180)));
  Modelica.Blocks.Sources.RealExpression setPoint_MT_Valve(y=8) annotation (
      Placement(transformation(
        origin={-90,30},
        extent={{10,-10},{-10,10}},
        rotation=0)));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_5(
    vleFluidType=sim.vleFluidType1,
    pressureStateID=5,
    pInitial(displayUnit="Pa") = 28.3208e5)
                                           annotation (Placement(transformation(
        extent={{6.0,6.0},{-6.0,-6.0}},
        rotation=180,
        origin={-132,-20})));
  TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_MT(
    useTimeConstant=true,
    tau=0.1,
    initialSensorValue=8)
    annotation (Placement(transformation(extent={{-4,-16},{4,-8}})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor3(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=90,
        origin={120,-40})));
  inner SystemInformationManager_1   sim(
    redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
    redeclare TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType3,
    redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType1,
    redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType2,
    redeclare TILMedia.LiquidTypes.TILMedia_Glysantin_60 liquidType1,
    redeclare TILMedia.VLEFluidTypes.BaseVLEFluid vleFluidType2(
      fixedMixingRatio=false,
      nc_propertyCalculation=1,
      vleFluidNames={"Refprop.HYDROGEN.FLD"},
      mixingRatio_propertyCalculation={1}))
    annotation (Placement(transformation(extent={{222,212},{242,232}}, rotation=
           0)));

  TIL.HeatExchangers.FinAndTube.MoistAirVLEFluid.CrossFlowHX LTCabinet(
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
    nCells=10,
    vleFluidType=sim.vleFluidType1,
    initVLEFluid="linearEnthalpyDistribution",
    m_flowVLEFluidStart=0.05,
    m_flowMoistAirStart=0.5,
    alphaAInitialVLEFluid=3000,
    pressureStateID=7,
    hInitialVLEFluid_CellN=444e3,
    redeclare model TubeSideHeatTransferModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
        (constantAlpha=6000),
    redeclare model FinSideHeatTransferModel =
        TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
        (constantAlpha=100),
    hxGeometry(
      finnedTubeLength=0.6,
      nTubeSideParallelHydraulicFlows=4,
      nSerialTubes=12,
      nParallelTubes=10),
    hInitialVLEFluid_Cell1=199e3,
    TInitialWall(displayUnit="K") = 273.15 - 35,
    pVLEFluidStart=1200000) annotation (Placement(transformation(
        origin={-60,-160},
        extent={{14,-14},{-14,14}},
        rotation=180)));
  TIL.VLEFluidComponents.Valves.OrificeValve LTValve(
    effectiveFlowAreaFixed=0.3e-5,
    use_effectiveFlowAreaInput=true,
    portA(p(start=35e5))) annotation (Placement(transformation(
        extent={{-8.0,-4.0},{8.0,4.0}},
        rotation=0,
        origin={-210,-160})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_7(
                                             pressureStateID=7, pInitial(
        displayUnit="Pa") = 11.0238e5)                          annotation (
      Placement(transformation(
        extent={{6.0,6.0},{-6.0,-6.0}},
        rotation=180,
        origin={-130,-158})));
  TIL.GasComponents.Volumes.Volume volume_LTCabinet(
    m_flowStart=5,
    volume=8.25,
    TInitial(displayUnit="K") = 273.15 - 22) "8.25"
                        annotation (Placement(transformation(
        extent={{-4.0,-8.0},{4.0,8.0}},
        rotation=90,
        origin={-64,-220})));
  TIL.OtherComponents.Thermal.HeatBoundary heatBoundary_LTCabinet(
    TFixed(displayUnit="K") = 273.15 + 21,
    boundaryType="Q_flow",
    Q_flowFixed(displayUnit="kW") = -17500,
    use_heatFlowRateInput=false) annotation (Placement(transformation(
        extent={{-4.0,-6.0},{4.0,6.0}},
        rotation=0,
        origin={-80,-220})));
  TIL.OtherComponents.Controllers.PIController PI_LTValve(
    yMin=1e-12,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    Ti=20,
    k=0.05e-7,
    yMax=1e-4,
    yInitial=1.07706e-6)
               annotation (Placement(transformation(extent={{-124,-116},{-136,
            -104}},
          rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_LPValve(y=11)
                                                               annotation (
      Placement(transformation(extent={{-80,-120},{-100,-100}},rotation=0)));
  TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_LT(
    useTimeConstant=true,
    tau=0.1,
    initialSensorValue=8)
    annotation (Placement(transformation(extent={{-4,-156},{4,-148}})));
  TIL.VLEFluidComponents.Compressors.EffCompressor HPComp_FI(
    nFixed=35,
    displacement=0.000204203,
    use_mechanicalPort=true)            annotation (Placement(transformation(
        extent={{-8.0,-8.0},{8.0,8.0}},
        rotation=0,
        origin={150,172})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_MP2(useTimeConstant=true,
      initialSensorValue=2800000) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={140,126})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs(
      use_nInput=true, nFixed=40) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={170,170})));
  TIL.OtherComponents.Controllers.PIController PI_HPComp(
    yMax=2,
    yMin=0,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    Ti=10,
    k=1e-4,
    yInitial=0.553369)
            annotation (Placement(transformation(extent={{226,158},{214,170}},
          rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_HP_Comp(y=28e5) annotation (
      Placement(transformation(
        origin={250,164},
        extent={{10,-10},{-10,10}},
        rotation=0)));
  TIL.VLEFluidComponents.Compressors.EffCompressor HPComp_noFI(
    nFixed=35,
    use_mechanicalPort=true,
    displacement=0.000204203)           annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=0,
        origin={90,172})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_HPCompIn(
    volume=1e-2,
    pressureStateID=1,
    hInitial=458e3) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=180,
        origin={120,150})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_HPCompOut(
    volume=1e-2,
    pressureStateID=2,
    hInitial=518e3) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={120,190})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs2(
      use_nInput=true, nFixed=50) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={110,170})));
  CompressorController compressorControllerHP(n1_max=70, n2_max=50) annotation (
     Placement(transformation(extent={{200,154},{180,174}}, rotation=0)));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_2(
    vleFluidType=sim.vleFluidType1,
    pressureStateID=2,
    pInitial(displayUnit="Pa") = 60e5) annotation (Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=0,
        origin={50,200})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_from_IHX(
    volume=1e-2,
    pressureStateID=10,
    hInitial=457.582e3)
                    annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=90,
        origin={122,80})));

  TIL.VLEFluidComponents.Valves.OrificeValve HPValve(
    mdotSmooth=0.0005,
    vleFluidType=sim.vleFluidType1,
    x(start=0.5),
    effectiveFlowAreaFixed=2e-6,
    use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
        extent={{-8.0,-4.0},{8.0,4.0}},
        rotation=270,
        origin={-260,150})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_HP(
    useTimeConstant=true,
    tau=5,
    initialSensorValue=6000000) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={-240,180})));
  TIL.OtherComponents.Controllers.PIController PI_HPValve(
    yMax=0.1e-2,
    yMin=0.1e-13,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    activationTime=-30000 + 20,
    yInitial=5.47292e-6,
    k=1e-11,
    Ti=1000) annotation (Placement(transformation(
        origin={-210,150},
        extent={{-6,-6},{6,6}},
        rotation=180)));
  TIL.VLEFluidComponents.Separators.Separator MPReciever(
    vleFluidType=sim.vleFluidType1,
    mdotStart=1,
    pressureStateID=3,
    hStart=223e3,
    V(displayUnit="l") = 0.4,
    initialFillingLevel=0.3)  annotation (Placement(transformation(
        extent={{-6.0,-10.0},{6.0,10.0}},
        rotation=0,
        origin={-220,76})));
  TIL.VLEFluidComponents.Valves.OrificeValve RecValve(effectiveFlowAreaFixed=
        0.9e-5, use_effectiveFlowAreaInput=true) annotation (Placement(
        transformation(
        extent={{-8.0,-4.0},{8.0,4.0}},
        rotation=0,
        origin={-120,80})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_3(
      pInitial(displayUnit="Pa") = 34.9e5, pressureStateID=3) annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=90,
        origin={-260,120})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_MP(useTimeConstant=true,
      initialSensorValue=3490000) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={-170,88})));
  TIL.OtherComponents.Controllers.PIController PI_RecValve(
    yMin=1e-10,
    yMax=1e-1,
    k=1e-8,
    Ti=10,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    yInitial=2.75172e-6) annotation (Placement(transformation(extent={{-176,104},
            {-164,116}}, rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_RecValve(y=34.9e5)
    annotation (Placement(transformation(extent={{-220,100},{-200,120}},
          rotation=0)));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor4(dp_nominal=10000) annotation (Placement(
        transformation(
        extent={{-6.0,-2.0},{6.0,2.0}},
        rotation=90,
        origin={-260,50})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_05(stateViewerIndex=5)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-280,98})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_09(stateViewerIndex=9)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={152,-48})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_02(stateViewerIndex=2)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={100,126})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_03(stateViewerIndex=3)
    annotation (Placement(transformation(extent={{16,204},{24,212}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_12(stateViewerIndex=12)
    annotation (Placement(transformation(extent={{-144,84},{-136,92}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_15(stateViewerIndex=15)
    annotation (Placement(transformation(extent={{16,-16},{24,-8}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_08(stateViewerIndex=8)
    annotation (Placement(transformation(extent={{16,-156},{24,-148}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_07(stateViewerIndex=7)
    annotation (Placement(transformation(extent={{-94,-156},{-86,-148}})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor5(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=90,
        origin={120,94})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_1(
      pressureStateID=1, pInitial(displayUnit="Pa") = 28e5) annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=90,
        origin={120,108})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_9(
                                             pressureStateID=9, pInitial(
        displayUnit="Pa") = 28.257e5)                           annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=90,
        origin={120,-62})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_10(
                                             pressureStateID=10, pInitial(
        displayUnit="Pa") = 28.121e5)                            annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=90,
        origin={122,30})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor2(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=0,
        origin={48,-160})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_8(
                                         pressureStateID=8, pInitial(
        displayUnit="Pa") = 11e5)                           annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=0,
        origin={78,-160})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor6(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=0,
        origin={50,-20})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_6(
                                             pressureStateID=6, pInitial(
        displayUnit="Pa") = 28.2332e5)                          annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=0,
        origin={80,-20})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_14(stateViewerIndex=14)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-176,-8})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_01(stateViewerIndex=1)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={100,52})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_06(stateViewerIndex=6)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-240,8})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_11(stateViewerIndex=11)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-80,88})));
  TIL.OtherComponents.Controllers.PIController PI_Fan_LT(
    yMin=0.1,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    Ti=100,
    yMax=5,
    k=0.05,
    yInitial=1.7033)
            annotation (Placement(transformation(extent={{-116,-200},{-104,-212}},
          rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_FanLTCab(y=273.15 - 22)
    annotation (Placement(transformation(extent={{-160,-216},{-140,-196}},
          rotation=0)));
  TIL.GasComponents.Sensors.Sensor_T sensor_T_LT(useTimeConstant=true,
      initialSensorValue=251.15) annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={-90,-180})));
  TIL.OtherComponents.Controllers.PIController PI_Fan_MT(
    yMin=0.00001,
    yMax=10,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    k=0.1,
    Ti=100,
    yInitial=6.918,
    activationTime=0)
           annotation (Placement(transformation(extent={{-116,-60},{-104,-72}},
          rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_FanMTCab(y=273.15 + 3)
    annotation (Placement(transformation(extent={{-160,-76},{-140,-56}},
                                                                       rotation=
           0)));
  TIL.GasComponents.Sensors.Sensor_T sensor_T_MT(useTimeConstant=true,
    tau=5,
    initialSensorValue=276.15)   annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=0,
        origin={-90,-40})));
  TIL.HeatExchangers.TubeAndTube.VLEFluidVLEFluid.ParallelFlowHX InnerHX(
    thermalResistanceInputType="l, A, solid",
    nCells=10,
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    cellOrientation_a="A",
    cellOrientation_b="B",
    vleFluidType_a=sim.vleFluidType1,
    vleFluidType_b=sim.vleFluidType1,
    initVLEFluid_b="linearEnthalpyDistribution",
    crossSection=10,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
    alphaAInitialVLEFluid_a=390,
    alphaAInitialVLEFluid_b=390,
    m_flowStart_a=1,
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=3900),
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=3900),
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      nParallelTubes_a=40,
      nParallelTubes_b=40,
      innerPerimeterNonCircular_a=0.01,
      innerPerimeterNonCircular_b=0.01,
      innerCrossSectionalAreaNonCircular_a=4,
      innerCrossSectionalAreaNonCircular_b=4,
      length_a=2,
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      length_b=2,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular),
    hInitialVLEFluid_a=200e3,
    hInitialVLEFluid_b_CellN=430e3,
    initVLEFluid_a="linearEnthalpyDistribution",
    hInitialVLEFluid_a_CellN=200e3,
    pressureStateID_a=3,
    pressureStateID_b=10,
    hInitialVLEFluid_b_Cell1=446e3,
    hInitialVLEFluid_a_Cell1=198e3,
    pStart_a=3400000,
    pStart_b=2800000) annotation (Placement(transformation(
        origin={-48,72},
        extent={{-14,-14},{14,14}},
        rotation=0)));

  TIL.LiquidComponents.Boundaries.Boundary liquidSource(
    boundaryType="p",
    TFixed(displayUnit="K") = 273.15 + 7,
    use_temperatureInput=true) annotation (Placement(transformation(
        extent={{4,-10},{-4,10}},
        rotation=180,
        origin={-96,216})));
  TIL.HeatExchangers.TubeAndTube.VLEFluidLiquid.ParallelFlowHX
    gasCooler_EnergyWell(
    nCells=10,
    thermalResistanceInputType="l, A, solid",
    heatCapacityInputType="C",
    heatCapacity=1,
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
    heatDistance=0.001,
    initLiquid_b="linearTemperatureDistribution",
    initVLEFluid_a="linearEnthalpyDistribution",
    m_flowStart_a=0.15,
    pressureStateID=2,
    alphaAInitialVLEFluid_a=27000,
    m_flowStart_b=5,
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=35000),
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlphaA
        (constantAlphaA=35000),
    redeclare TIL.HeatExchangers.TubeAndTube.Geometry.TubeAndTubeGeometry
      hxGeometry(
      crossSectionType_a=TIL.Internals.CrossSectionType.Circular,
      crossSectionType_b=TIL.Internals.CrossSectionType.Circular,
      nParallelTubes_a=40,
      nParallelTubes_b=40,
      length_a=40,
      length_b=40),
    crossSection=50,
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.TubeAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
    hInitialVLEFluid_a_Cell1=508e3,
    hInitialVLEFluid_a_CellN=220e3,
    TInitialLiquid_b_Cell1=296.75,
    TInitialLiquid_b_CellN=280.15,
    pStart_a=4500000) annotation (Placement(transformation(extent={{-36,194},{
            -64,222}},  rotation=0)));

  TIL.LiquidComponents.Boundaries.Boundary liquidSink(boundaryType="p", TFixed=
        273.15 + 5) annotation (Placement(transformation(
        extent={{-4,-10},{4,10}},
        rotation=180,
        origin={-22,216})));
  TIL.LiquidComponents.Pumps.SimplePump pump_gasCooler(
    presetVariableType="m_flow",
    V_flowFixed=0.3,
    m_flowFixed=2) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=270,
        origin={-80,216})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_04(stateViewerIndex=4)
    annotation (Placement(transformation(extent={{-264,204},{-256,212}})));

  TIL.GasComponents.Fans.SimpleFan fan_MT(
    presetVariableType="m_flow",
    m_flowFixed=1,
    use_massFlowRateInput=true,
    eta=0.95)
    annotation (Placement(transformation(extent={{-68,-68},{-52,-52}})));
  TIL.GasComponents.Fans.SimpleFan fan_LT(
    presetVariableType="m_flow",
    m_flowFixed=1,
    use_massFlowRateInput=true)
    annotation (Placement(transformation(extent={{-68,-208},{-52,-192}})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor8(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=90,
        origin={120,10})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_MT_LT_1(
    volume=1e-2,
    h(start=197e3),
    pressureStateID=4,
    hInitial=199e3)    annotation (Placement(transformation(
        origin={-260,-20},
        extent={{-4,-4},{4,4}},
        rotation=270)));

  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_10(stateViewerIndex=10)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={140,52})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_13(stateViewerIndex=13)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={-280,8})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_16(stateViewerIndex=16)
    annotation (Placement(transformation(extent={{60,-16},{68,-8}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint_17(stateViewerIndex=17)
    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=0,
        origin={140,0})));
  Modelica.Blocks.Sources.Constant
                               heatSinkTemperature(k=273.15 + 7)
    annotation (Placement(transformation(extent={{-160,210},{-140,230}})));
  Modelica.Blocks.Sources.RealExpression COP(y=(volume_MTCabinet.heatPort.Q_flow
         + volume_LTCabinet.heatPort.Q_flow)/(HPComp_noFI.shaftPower +
        HPComp_FI.shaftPower + MPComp_noFI.shaftPower + MPComp_FI.shaftPower))
    annotation (Placement(transformation(extent={{200,-22},{220,-2}})));
  TIL.VLEFluidComponents.Sensors.Sensor_V_flow
    sensor_V_flow_LT_compressor_inlet annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=90,
        origin={120,-144})));
  TIL.VLEFluidComponents.Sensors.Sensor_V_flow
    sensor_V_flow_MT_compressor_inlet annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=90,
        origin={120,132})));
  Modelica.Blocks.Sources.Constant
                               setPointHighPressure(k=60e5)
    annotation (Placement(transformation(extent={{-160,140},{-180,160}})));
  Modelica.Blocks.Continuous.Integrator integrator(initType=Modelica.Blocks.Types.Init.InitialState,
      y_start=0)
    annotation (Placement(transformation(extent={{256,-60},{276,-40}})));
  Modelica.Blocks.Sources.RealExpression eletricDemand(y=(HPComp_noFI.shaftPower
         + HPComp_FI.shaftPower + MPComp_noFI.shaftPower + MPComp_FI.shaftPower))
    annotation (Placement(transformation(extent={{200,-60},{220,-40}})));
  TIL.VLEFluidComponents.Boundaries.Boundary               boundary_b_source(
    vleFluidType=sim.vleFluidType2,
    hFixed=4382e3,
    V_flowFixed=-20,
    streamVariablesInputType="T",
    m_flowFixed=-0.06,
    boundaryType="p",
    TFixed=298.15,
    pFixed=2500000)      annotation (Placement(transformation(extent={{34,-354},
            {42,-334}},
                     rotation=0)));
  TIL.VLEFluidComponents.Boundaries.Boundary                boundary_b_sink(
    vleFluidType=sim.vleFluidType2,
    hFixed=3407e3,
    streamVariablesInputType="T",
    m_flowFixed=0.06,
    TFixed=233.15)
    annotation (Placement(transformation(extent={{-150,-352},{-142,-332}},
                                                                     rotation=0)));
  TIL.HeatExchangers.Plate.VLEFluidVLEFluid.ParallelFlowHX hx(
    redeclare model PressureDropModel_a =
        TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
    redeclare model HeatTransferModel_b =
        TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
        (constantAlpha=2000),
    redeclare model PressureDropModel_b =
        TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
    vleFluidType_b=sim.vleFluidType2,
    redeclare model HeatTransferModel_a =
        TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
        (constantAlpha=2000),
    redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
    redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
      numberOfPlates=200,
      length=0.4,
      width=0.2),
    nCells=25,
    pressureStateID_b=20,
    pressureStateID_a=11,
    hInitialVLEFluid_b=3e6,
    m_flowStart_b=0.06,
    m_flowStart_a=0.22,
    hInitialVLEFluid_a=99e3,
    initVLEFluid_b="linearEnthalpyDistribution",
    hInitialVLEFluid_b_CellN=3e6,
    hInitialVLEFluid_b_Cell1=3.65e6,
    pStart_a=600000,
    pStart_b=35000000)
    annotation (Placement(transformation(extent={{-66,-376},{-38,-348}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint(stateViewerIndex=2,
      vleFluidType=sim.vleFluidType2)
    annotation (Placement(transformation(extent={{-98,-330},{-90,-322}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1,
      vleFluidType=sim.vleFluidType2)
    annotation (Placement(transformation(extent={{-32,-330},{-24,-322}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(stateViewerIndex=5)
    annotation (Placement(transformation(extent={{-112,-380},{-104,-372}})));
  TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(stateViewerIndex=4)
    annotation (Placement(transformation(extent={{-22,-374},{-14,-366}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC(vleFluidType=sim.vleFluidType2)
    annotation (Placement(transformation(extent={{-18,-330},{-10,-322}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC1(vleFluidType=sim.vleFluidType2)
    annotation (Placement(transformation(extent={{-82,-330},{-74,-322}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC2
    annotation (Placement(transformation(extent={{-96,-380},{-88,-372}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC3
    annotation (Placement(transformation(extent={{-6,-374},{2,-366}})));
  TIL.VLEFluidComponents.FillingStations.FillingStation fillingStation(
      vleFluidType=sim.vleFluidType2, use_totalMassInput=false)
    annotation (Placement(transformation(extent={{-136,-364},{-128,-340}})));
  TIL.VLEFluidComponents.Compressors.SimpleCompressor simpleCompressor(
    vleFluidType=sim.vleFluidType2,
    h_out=4129e3,
    presetVariableType="m_flow",
    m_flowFixed=0.06,
    dischargeConditionType="h",
    T_out=303.15) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=90,
        origin={22,-344})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_MT_LT_3(
    volume=1e-2,
    h(start=197e3),
    hInitial=199e3,
    pressureStateID=4) annotation (Placement(transformation(
        origin={-266,-160},
        extent={{-4,-4},{4,4}},
        rotation=270)));
  TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_LT1(
    useTimeConstant=true,
    tau=0.1,
    initialSensorValue=8)
    annotation (Placement(transformation(extent={{40,-308},{48,-300}})));
  TIL.OtherComponents.Controllers.PIController PI_LTValve1(
    yMin=1e-12,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    Ti=20,
    k=0.05e-7,
    yMax=1e-4,
    yInitial=1.07706e-6)
               annotation (Placement(transformation(extent={{-168,-332},{-180,
            -320}},
          rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_LPValve1(y=8)
                                                               annotation (
      Placement(transformation(extent={{-128,-310},{-148,-290}},
                                                               rotation=0)));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_11(
      pressureStateID=11, pInitial(displayUnit="Pa") = 8e5)     annotation (
      Placement(transformation(
        extent={{6.0,6.0},{-6.0,-6.0}},
        rotation=180,
        origin={-174,-378})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_20(
    pressureStateID=20,
    pInitial(displayUnit="bar") = 35000000,
    vleFluidType=sim.vleFluidType2)                             annotation (
      Placement(transformation(
        extent={{6.0,6.0},{-6.0,-6.0}},
        rotation=180,
        origin={-12,-354})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor(dp_nominal=100)
    annotation (Placement(transformation(extent={{46,-374},{58,-370}})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_12(
    pressureStateID=12,
    fixedInitialPressure=false,
    pInitial(displayUnit="Pa") = 8e5,
    initPressure="fixedInitialPressure")                    annotation (
      Placement(transformation(
        extent={{-6.0,-6.0},{6.0,6.0}},
        rotation=0,
        origin={94,-372})));
  TIL.VLEFluidComponents.Compressors.EffCompressor effCompressor(
      use_mechanicalPort=true, displacement=7.34e-5)
    annotation (Placement(transformation(extent={{74,-274},{90,-258}})));
  TIL.VLEFluidComponents.Compressors.EffCompressor effCompressor1(
      use_mechanicalPort=true, displacement=7.34e-5)
    annotation (Placement(transformation(extent={{134,-274},{150,-258}})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor1(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=90,
        origin={258,-132})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_13(
      pressureStateID=13, pInitial(displayUnit="Pa") = 28.257e5)
                                                 annotation (Placement(
        transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={120,-212})));
  TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState_14(
      pressureStateID=14, pInitial(displayUnit="Pa") = 28.257e5)
                                                 annotation (Placement(
        transformation(
        extent={{-7,-6},{7,6}},
        rotation=90,
        origin={259,-164})));
  TIL.VLEFluidComponents.HydraulicResistors.LinearHydraulicResistor
    linearHydraulicResistor7(mdot_nominal=0.3, dp_nominal=10000) annotation (
      Placement(transformation(
        extent={{-6,-2},{6,2}},
        rotation=90,
        origin={120,-188})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_MT_LT_5(
    volume=1e-2,
    pressureStateID=12,
    hInitial=300e3)    annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=180,
        origin={120,-296})));
  TIL.VLEFluidComponents.Sensors.Sensor_V_flow
    sensor_V_flow_LT_compressor_inlet1
                                      annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=90,
        origin={120,-316})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p
    annotation (Placement(transformation(extent={{136,-342},{144,-334}})));
  CompressorController compressorControllerMP1(
    n1_max=70,
    n2_max=50,
    n2_min=0) annotation (Placement(transformation(extent={{198,-284},{178,-264}},
          rotation=0)));
  TIL.OtherComponents.Controllers.PIController PI_LPComp1(
    yMax=2,
    yMin=0,
    Ti=10,
    k=0.005,
    controllerType="PI",
    initType="initialOutput",
    invertFeedback=true,
    yInitial=0.73)       annotation (Placement(transformation(extent={{230,-280},
            {218,-268}},rotation=0)));
  Modelica.Blocks.Sources.RealExpression setPoint_LP_Comp1(y=8e5) annotation (
      Placement(transformation(
        origin={262,-274},
        extent={{10,-10},{-10,10}},
        rotation=0)));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs1(
      use_nInput=true, nFixed=45) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={156,-270})));
  TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundaryWithInputs3(
      use_nInput=true, nFixed=45) annotation (Placement(transformation(
        extent={{-4.0,-10.0},{4.0,10.0}},
        rotation=180,
        origin={96,-266})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_LT_Cab_zus(
    volume=1e-2,
    hInitial=444e3,
    pressureStateID=8)
                    annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=180,
        origin={120,-124})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_LT_H2(
    volume=1e-2,
    hInitial=446e3,
    pressureStateID=14)
                    annotation (Placement(transformation(
        extent={{-4.0,-4.0},{4.0,4.0}},
        rotation=90,
        origin={204,-168})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction_MT_LT_2(
    pressureStateID=6,
    volume=1e-2,
    hInitial=446e3) annotation (Placement(transformation(
        extent={{-4,-4},{4,4}},
        rotation=90,
        origin={120,-20})));
  TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction(
      pressureStateID=13, hInitial=446e3)
    annotation (Placement(transformation(extent={{118,-236},{126,-228}})));
  TIL.VLEFluidComponents.Valves.OrificeValve MTValve1(
                                                     effectiveFlowAreaFixed=
        0.2e-5, use_effectiveFlowAreaInput=true) annotation (Placement(
        transformation(
        extent={{-8.0,-4.0},{8.0,4.0}},
        rotation=0,
        origin={-236,-378})));
  TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p1
    annotation (Placement(transformation(extent={{88,-222},{96,-214}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC4
    annotation (Placement(transformation(extent={{-72,230},{-64,238}})));
  TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC5
    annotation (Placement(transformation(extent={{-30,230},{-22,238}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC6
    annotation (Placement(transformation(extent={{-118,210},{-110,218}})));
  TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC7
    annotation (Placement(transformation(extent={{-12,212},{-4,220}})));
equation

  connect(MPComp_FI.rotatoryFlange, rotatoryBoundaryWithInputs4.rotatoryFlange)
    annotation (Line(
      points={{158,-100},{170,-100}},
      color={135,135,135},
      thickness=0.5,
      smooth=Smooth.None));
  connect(MPComp_noFI.rotatoryFlange, rotatoryBoundaryWithInputs5.rotatoryFlange)
    annotation (Line(
      points={{98,-100},{110,-100}},
      color={135,135,135},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_MPCompOut.portC, MPComp_FI.portB) annotation (Line(
      points={{122,-82},{150,-82},{150,-92}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(compressorControllerMP.n1, rotatoryBoundaryWithInputs4.n_in)
    annotation (Line(
      points={{179,-100},{174,-100}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(compressorControllerMP.n2, rotatoryBoundaryWithInputs5.n_in)
    annotation (Line(
      points={{179,-112},{130,-112},{130,-100},{114,-100}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(heatBoundary_MTCabinet.heatPort, volume_MTCabinet.heatPort)
    annotation (Line(
      points={{-80,-80},{-70,-80}},
      color={204,0,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(MTValve.portB, pressureState_5.portB) annotation (Line(
      points={{-202,-20},{-138,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_5.portA, MTCabinet.portA_vle) annotation (Line(
      points={{-126,-20},{-74,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_MT.port, MTCabinet.portB_vle) annotation (Line(
      points={{0,-16},{0,-20},{-46,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(heatBoundary_LTCabinet.heatPort, volume_LTCabinet.heatPort)
    annotation (Line(
      points={{-80,-220},{-70,-220}},
      color={204,0,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(LTValve.portB, pressureState_7.portB) annotation (Line(
      points={{-202,-160},{-170,-160},{-170,-158},{-136,-158}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_7.portA, LTCabinet.portA_vle) annotation (Line(
      points={{-124,-158},{-100,-158},{-100,-160},{-74,-160}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_LT.port, LTCabinet.portB_vle) annotation (Line(
      points={{0,-156},{0,-160},{-46,-160}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(HPComp_FI.portA, junction_HPCompIn.portA) annotation (Line(
      points={{150,164},{150,150},{124,150}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(HPComp_noFI.portA, junction_HPCompIn.portC) annotation (Line(
      points={{90,164},{90,150},{116,150}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_HPCompOut.portC, HPComp_FI.portB) annotation (Line(
      points={{124,190},{150,190},{150,180}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_HPCompOut.portA, HPComp_noFI.portB) annotation (Line(
      points={{116,190},{90,190},{90,180}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(HPComp_noFI.rotatoryFlange, rotatoryBoundaryWithInputs2.rotatoryFlange)
    annotation (Line(
      points={{98,172},{104,172},{104,170},{110,170}},
      color={135,135,135},
      thickness=0.5,
      smooth=Smooth.None));
  connect(compressorControllerHP.n1, rotatoryBoundaryWithInputs.n_in)
    annotation (Line(
      points={{179,170},{174,170}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(compressorControllerHP.n2, rotatoryBoundaryWithInputs2.n_in)
    annotation (Line(
      points={{179,158},{130,158},{130,170},{114,170}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_HP.port, HPValve.portA) annotation (Line(
      points={{-240,176},{-240,176},{-240,172},{-260,172},{-260,158}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(MPReciever.portGas, RecValve.portA) annotation (Line(
      points={{-215,80},{-128,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_3.portB, MPReciever.portInlet) annotation (Line(
      points={{-260,114},{-260,80},{-225,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(HPValve.portB, pressureState_3.portA) annotation (Line(
      points={{-260,142},{-260,126}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_MP.port, MPReciever.portGas) annotation (Line(
      points={{-170,84},{-170,80},{-215,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor4.portA, pressureState_4.portA) annotation (
      Line(
      points={{-260,44},{-260,36}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_15.sensorPort, MTCabinet.portB_vle) annotation (Line(
      points={{20,-16},{20,-20},{-46,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_07.sensorPort, LTCabinet.portA_vle) annotation (Line(
      points={{-90,-156},{-90,-160},{-74,-160}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_08.sensorPort, LTCabinet.portB_vle) annotation (Line(
      points={{20,-156},{20,-160},{-46,-160}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_1.portB, linearHydraulicResistor5.portB) annotation (
      Line(
      points={{120,102},{120,100}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_from_IHX.portA, pressureState_10.portA) annotation (Line(
      points={{122,76},{122,36}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor5.portA, junction_from_IHX.portC) annotation (
      Line(
      points={{120,88},{120,84},{122,84}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor6.portB, pressureState_6.portB) annotation (
      Line(
      points={{56,-20},{74,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_01.sensorPort, junction_from_IHX.portA) annotation (Line(
      points={{100,48},{100,44},{122,44},{122,76}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_12.sensorPort, RecValve.portA) annotation (Line(
      points={{-140,84},{-140,80},{-128,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_05.sensorPort, MPReciever.portInlet) annotation (Line(
      points={{-280,94},{-280,90},{-260,90},{-260,80},{-225,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_14.sensorPort, MTValve.portB) annotation (Line(
      points={{-176,-12},{-176,-20},{-202,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));

  connect(junction_from_IHX.portB, InnerHX.portB_b) annotation (Line(
      points={{118,80},{-34,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(MPReciever.portLiquid, InnerHX.portB_a) annotation (Line(
      points={{-220,66},{-220,50},{-20,50},{-20,64},{-34,64}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));

  connect(InnerHX.portA_a, linearHydraulicResistor4.portB) annotation (Line(
      points={{-62,64},{-260,64},{-260,56}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(RecValve.portB, InnerHX.portA_b) annotation (Line(
      points={{-112,80},{-62,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_11.sensorPort, InnerHX.portA_b) annotation (Line(
      points={{-80,84},{-80,80},{-62,80}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(HPValve.portA, gasCooler_EnergyWell.portB_a) annotation (Line(
      points={{-260,158},{-260,200},{-64,200}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pump_gasCooler.portB, gasCooler_EnergyWell.portB_b) annotation (Line(
      points={{-72,216},{-64,216}},
      color={0,170,238},
      thickness=0.5,
      smooth=Smooth.None));
  connect(liquidSource.port, pump_gasCooler.portA) annotation (Line(
      points={{-96,216},{-88,216}},
      color={0,170,238},
      thickness=0.5,
      smooth=Smooth.None));
  connect(gasCooler_EnergyWell.portA_b, liquidSink.port) annotation (Line(
      points={{-36,216},{-22,216}},
      color={0,170,238},
      thickness=0.5,
      smooth=Smooth.None));

  connect(LTCabinet.portA_gas, fan_LT.portB) annotation (Line(
      points={{-60,-174},{-60,-192}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(fan_LT.portA, volume_LTCabinet.portB) annotation (Line(
      points={{-60,-208},{-60,-216}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));

  connect(sensor_T_MT.sensorValue, PI_Fan_MT.u_m) annotation (Line(
      points={{-90,-38},{-110,-38},{-110,-60.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(setPoint_FanMTCab.y, PI_Fan_MT.u_s) annotation (Line(
      points={{-139,-66},{-115.6,-66}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_T_LT.sensorValue, PI_Fan_LT.u_m) annotation (Line(
      points={{-90,-178},{-110,-178},{-110,-200.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_Fan_LT.u_s, setPoint_FanLTCab.y) annotation (Line(
      points={{-115.6,-206},{-139,-206}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(MTCabinet.portA_gas, fan_MT.portB) annotation (Line(
      points={{-60,-34},{-60,-52}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(fan_MT.portA, volume_MTCabinet.portB) annotation (Line(
      points={{-60,-68},{-60,-76}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_MT_LT_1.portB, MTValve.portA) annotation (Line(
      points={{-256,-20},{-218,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_10.portB, linearHydraulicResistor8.portB) annotation (
      Line(
      points={{122,24},{122,20},{120,20},{120,16}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(pressureState_4.portB, junction_MT_LT_1.portA) annotation (Line(
      points={{-260,24},{-260,-16}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_06.sensorPort, pressureState_4.portB) annotation (Line(
      points={{-240,4},{-240,0},{-260,0},{-260,24}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_04.sensorPort, HPValve.portA) annotation (Line(
      points={{-260,204},{-260,158}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(gasCooler_EnergyWell.portA_a, statePoint_03.sensorPort) annotation (
      Line(
      points={{-36,200},{20,200},{20,204}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(setPoint_RecValve.y, PI_RecValve.u_s) annotation (Line(
      points={{-199,110},{-175.6,110}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_MP.sensorValue, PI_RecValve.u_m) annotation (Line(
      points={{-170,90.2},{-170,104.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_HPValve.u_m, sensor_HP.sensorValue) annotation (Line(
      points={{-210,155.8},{-210,182.2},{-240,182.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(pressureState_2.portB, gasCooler_EnergyWell.portA_a) annotation (Line(
      points={{44,200},{-36,200}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor6.portA, MTCabinet.portB_vle) annotation (Line(
      points={{44,-20},{-46,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor2.portA, LTCabinet.portB_vle) annotation (Line(
      points={{42,-160},{-46,-160}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_LT.sensorValue, PI_LTValve.u_m) annotation (Line(
      points={{0,-149.8},{0,-126},{-130,-126},{-130,-115.8}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(setPoint_LPValve.y, PI_LTValve.u_s) annotation (Line(
      points={{-101,-110},{-124.4,-110}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_MP2.sensorValue, PI_HPComp.u_m) annotation (Line(
      points={{140,128.2},{220,128.2},{220,158.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(setPoint_HP_Comp.y, PI_HPComp.u_s) annotation (Line(
      points={{239,164},{225.6,164}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_LP.sensorValue, PI_LPComp.u_m) annotation (Line(
      points={{100,-133.8},{220,-133.8},{220,-111.8}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(setPoint_LP_Comp.y, PI_LPComp.u_s) annotation (Line(
      points={{239,-106},{225.6,-106}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(pressureState_9.portA, linearHydraulicResistor3.portA) annotation (
      Line(
      points={{120,-56},{120,-46}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(linearHydraulicResistor3.portA, statePoint_09.sensorPort) annotation (
     Line(
      points={{120,-46},{120,-50},{152,-50},{152,-52}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(MPComp_noFI.portB, junction_MPCompOut.portA) annotation (Line(
      points={{90,-92},{90,-82},{114,-82}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(setPoint_MT_Valve.y, PI_MTValve.u_s) annotation (Line(
      points={{-101,30},{-124.4,30}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_HPValve.y, HPValve.effectiveFlowArea_in) annotation (Line(
      points={{-216.4,150},{-255,150}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_RecValve.y, RecValve.effectiveFlowArea_in) annotation (Line(
      points={{-163.6,110},{-120,110},{-120,85}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_MTValve.y, MTValve.effectiveFlowArea_in) annotation (Line(
      points={{-136.4,30},{-210,30},{-210,-15}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_Fan_MT.y, fan_MT.m_flow_in) annotation (Line(
      points={{-103.6,-66},{-70,-66}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_LTValve.y, LTValve.effectiveFlowArea_in) annotation (Line(
      points={{-136.4,-110},{-210,-110},{-210,-155}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_Fan_LT.y, fan_LT.m_flow_in) annotation (Line(
      points={{-103.6,-206},{-70,-206}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_HPComp.y, compressorControllerHP.u) annotation (Line(
      points={{213.6,164},{202,164}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI_LPComp.y, compressorControllerMP.u) annotation (Line(
      points={{213.6,-106},{202,-106}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(MTCabinet.portB_gas, volume_MTCabinet.portA) annotation (Line(
      points={{-60,-6},{-60,0},{-20,0},{-20,-90},{-60,-90},{-60,-84}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(LTCabinet.portB_gas, volume_LTCabinet.portA) annotation (Line(
      points={{-60,-146},{-60,-140},{-20,-140},{-20,-230},{-60,-230},{-60,-224}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));

  connect(sensor_T_LT.port, fan_LT.portB) annotation (Line(
      points={{-90,-184},{-90,-188},{-60,-188},{-60,-192}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(fan_MT.portB, sensor_T_MT.port) annotation (Line(
      points={{-60,-52},{-60,-48},{-90,-48},{-90,-44},{-90,-44}},
      color={255,153,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_from_IHX.portA, statePoint_10.sensorPort) annotation (Line(
      points={{122,76},{122,44},{140,44},{140,48}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_13.sensorPort, pressureState_4.portB) annotation (Line(
      points={{-280,4},{-280,0},{-260,0},{-260,24}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_16.sensorPort, linearHydraulicResistor6.portB) annotation (
     Line(
      points={{64,-16},{64,-20},{56,-20}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(statePoint_17.sensorPort, linearHydraulicResistor8.portA) annotation (
     Line(
      points={{140,-4},{140,-8},{120,-8},{120,4}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_MT.sensorValue, PI_MTValve.u_m) annotation (Line(
      points={{0,-9.8},{0,8},{-130,8},{-130,24.2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_V_flow_MT_compressor_inlet.portA, pressureState_1.portA)
    annotation (Line(
      points={{120,129},{120,114}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(sensor_V_flow_MT_compressor_inlet.portB, junction_HPCompIn.portB)
    annotation (Line(
      points={{120,135},{120,146}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(junction_HPCompOut.portB, pressureState_2.portA) annotation (Line(
      points={{120,194},{120,200},{56,200}},
      color={153,204,0},
      thickness=0.5,
      smooth=Smooth.None));
  connect(eletricDemand.y, integrator.u) annotation (Line(
      points={{221,-50},{254,-50}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(setPointHighPressure.y, PI_HPValve.u_s) annotation (Line(
      points={{-181,150},{-204.4,150}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(heatSinkTemperature.y, liquidSource.T_in) annotation (Line(
      points={{-139,220},{-124,220},{-124,228},{-110,228},{-110,218},{-100,218}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(sensor_MP2.port, pressureState_1.portA) annotation (Line(
      points={{140,122},{140,118},{120,118},{120,114}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint_02.sensorPort, pressureState_1.portA) annotation (Line(
      points={{100,122},{100,118},{120,118},{120,114}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint1.sensorPort,hx. portB_b) annotation (Line(
      points={{-28,-330},{-28,-334},{-30,-334},{-30,-354},{-38,-354}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC.port,hx. portB_b) annotation (Line(
      points={{-14,-330},{-14,-344},{-30,-344},{-30,-354},{-38,-354}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC1.port,hx. portA_b) annotation (Line(
      points={{-78,-330},{-78,-354},{-66,-354}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint.sensorPort,hx. portA_b) annotation (Line(
      points={{-94,-330},{-94,-354},{-66,-354}},
      color={153,204,0},
      thickness=0.5));
  connect(hx.portA_b, fillingStation.portB) annotation (Line(
      points={{-66,-354},{-120,-354},{-120,-342},{-128,-342}},
      color={153,204,0},
      thickness=0.5));
  connect(fillingStation.portA, boundary_b_sink.port) annotation (Line(
      points={{-136,-342},{-146,-342}},
      color={153,204,0},
      thickness=0.5));
  connect(boundary_b_source.port, simpleCompressor.portA) annotation (Line(
      points={{38,-344},{30,-344}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_1.portC, junction_MT_LT_3.portA) annotation (Line(
      points={{-260,-24},{-264,-24},{-264,-156},{-266,-156}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_3.portB, LTValve.portA) annotation (Line(
      points={{-262,-160},{-218,-160}},
      color={153,204,0},
      thickness=0.5));
  connect(setPoint_LPValve1.y, PI_LTValve1.u_s) annotation (Line(points={{-149,
          -300},{-152,-300},{-152,-326},{-168.4,-326}}, color={0,0,127}));
  connect(sensor_LT1.sensorValue, PI_LTValve1.u_m) annotation (Line(points={{44,
          -301.8},{-80,-301.8},{-80,-302},{-120,-302},{-120,-331.8},{-174,
          -331.8}},                                         color={0,0,127}));
  connect(pressureState_20.portB, hx.portB_b) annotation (Line(
      points={{-18,-354},{-38,-354}},
      color={153,204,0},
      thickness=0.5));
  connect(pressureState_20.portA, simpleCompressor.portB) annotation (Line(
      points={{-6,-354},{4,-354},{4,-344},{14,-344}},
      color={153,204,0},
      thickness=0.5));
  connect(linearHydraulicResistor.portA, hx.portB_a) annotation (Line(
      points={{46,-372},{10,-372},{10,-394},{-28,-394},{-28,-370},{-38,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint3.sensorPort, hx.portB_a) annotation (Line(
      points={{-18,-374},{-18,-394},{-28,-394},{-28,-370},{-38,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC3.port, hx.portB_a) annotation (Line(
      points={{-2,-374},{-2,-394},{-28,-394},{-28,-370},{-38,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(pressureState_11.portA, hx.portA_a) annotation (Line(
      points={{-168,-378},{-148,-378},{-148,-392},{-66,-392},{-66,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(linearHydraulicResistor.portB, pressureState_12.portB) annotation (
      Line(
      points={{58,-372},{88,-372}},
      color={153,204,0},
      thickness=0.5));
  connect(linearHydraulicResistor7.portA, pressureState_13.portA) annotation (
      Line(
      points={{120,-194},{120,-206}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_V_flow_LT_compressor_inlet1.portB, junction_MT_LT_5.portB)
    annotation (Line(
      points={{120,-313},{120,-300}},
      color={153,204,0},
      thickness=0.5));

  connect(pressureState_12.portA, sensor_V_flow_LT_compressor_inlet1.portA)
    annotation (Line(
      points={{100,-372},{120,-372},{120,-319}},
      color={153,204,0},
      thickness=0.5));
  connect(rotatoryBoundaryWithInputs1.rotatoryFlange, effCompressor1.rotatoryFlange)
    annotation (Line(
      points={{156,-270},{154,-270},{154,-266},{150,-266}},
      color={135,135,135},
      thickness=0.5));
  connect(rotatoryBoundaryWithInputs3.rotatoryFlange, effCompressor.rotatoryFlange)
    annotation (Line(
      points={{96,-266},{90,-266}},
      color={135,135,135},
      thickness=0.5));
  connect(compressorControllerMP1.n1, rotatoryBoundaryWithInputs1.n_in)
    annotation (Line(points={{177,-268},{170,-268},{170,-270},{160,-270}},
        color={0,0,127}));
  connect(compressorControllerMP1.n2, rotatoryBoundaryWithInputs3.n_in)
    annotation (Line(points={{177,-280},{120,-280},{120,-266},{100,-266}},
        color={0,0,127}));
  connect(PI_LPComp1.y, compressorControllerMP1.u)
    annotation (Line(points={{217.6,-274},{200,-274}}, color={0,0,127}));
  connect(setPoint_LP_Comp1.y, PI_LPComp1.u_s) annotation (Line(points={{251,
          -274},{242,-274},{242,-274},{229.6,-274}}, color={0,0,127}));
  connect(sensor_p.port, sensor_V_flow_LT_compressor_inlet1.portA) annotation (
      Line(
      points={{140,-342},{130,-342},{130,-354},{120,-354},{120,-319}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_p.sensorValue, PI_LPComp1.u_m) annotation (Line(points={{140,
          -335.8},{224,-335.8},{224,-279.8}}, color={0,0,127}));
  connect(sensor_LT1.port, hx.portB_a) annotation (Line(
      points={{44,-308},{44,-372},{10,-372},{10,-394},{-28,-394},{-28,-370},{
          -38,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_LT_Cab_zus.portC, MPComp_noFI.portA) annotation (Line(
      points={{116,-124},{104,-124},{104,-108},{90,-108}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_LT_Cab_zus.portA, MPComp_FI.portA) annotation (Line(
      points={{124,-124},{140,-124},{140,-108},{150,-108}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_LT_H2.portA, linearHydraulicResistor7.portB) annotation (
      Line(
      points={{204,-172},{204,-182},{120,-182}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_2.portC, linearHydraulicResistor8.portA) annotation (
      Line(
      points={{120,-16},{120,4}},
      color={153,204,0},
      thickness=0.5));
  connect(pressureState_6.portA, junction_MT_LT_2.portB) annotation (Line(
      points={{86,-20},{116,-20}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_5.portC, effCompressor.portA) annotation (Line(
      points={{116,-296},{82,-296},{82,-274}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_5.portA, effCompressor1.portA) annotation (Line(
      points={{124,-296},{142,-296},{142,-274}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_V_flow_LT_compressor_inlet.portA, pressureState_8.portA)
    annotation (Line(
      points={{120,-147},{120,-160},{84,-160}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_V_flow_LT_compressor_inlet.portB, junction_LT_Cab_zus.portB)
    annotation (Line(
      points={{120,-141},{120,-128}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_LT_H2.portB, linearHydraulicResistor3.portB) annotation (
      Line(
      points={{200,-168},{176,-168},{176,-34},{120,-34}},
      color={153,204,0},
      thickness=0.5));
  connect(effCompressor.portB, junction.portA) annotation (Line(
      points={{82,-258},{84,-258},{84,-232},{118,-232}},
      color={153,204,0},
      thickness=0.5));
  connect(effCompressor1.portB, junction.portC) annotation (Line(
      points={{142,-258},{142,-232},{126,-232}},
      color={153,204,0},
      thickness=0.5));
  connect(junction.portB, pressureState_13.portB) annotation (Line(
      points={{122,-228},{122,-218},{120,-218}},
      color={153,204,0},
      thickness=0.5));
  connect(linearHydraulicResistor2.portB, pressureState_8.portB) annotation (
      Line(
      points={{54,-160},{72,-160}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_LP.port, pressureState_8.portA) annotation (Line(
      points={{100,-140},{100,-160},{84,-160}},
      color={153,204,0},
      thickness=0.5));
  connect(pressureState_14.portA, linearHydraulicResistor1.portA) annotation (
      Line(
      points={{259,-157},{259,-147.5},{258,-147.5},{258,-138}},
      color={153,204,0},
      thickness=0.5));
  connect(linearHydraulicResistor1.portB, junction_MT_LT_2.portA) annotation (
      Line(
      points={{258,-126},{190,-126},{190,-24},{120,-24}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_LT_H2.portC, pressureState_14.portB) annotation (Line(
      points={{204,-164},{232,-164},{232,-171},{259,-171}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MPCompOut.portB, pressureState_9.portB) annotation (Line(
      points={{118,-78},{120,-78},{120,-68}},
      color={153,204,0},
      thickness=0.5));
  connect(PI_LTValve1.y, MTValve1.effectiveFlowArea_in) annotation (Line(points={{-180.4,
          -326},{-236,-326},{-236,-373}},                     color={0,0,127}));
  connect(MTValve1.portB, pressureState_11.portB) annotation (Line(
      points={{-228,-378},{-180,-378}},
      color={153,204,0},
      thickness=0.5));
  connect(junction_MT_LT_3.portC, MTValve1.portA) annotation (Line(
      points={{-266,-164},{-266,-378},{-244,-378}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_p1.port, pressureState_13.portB) annotation (Line(
      points={{92,-222},{122,-222},{122,-218},{120,-218}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC2.port, hx.portA_a) annotation (Line(
      points={{-92,-380},{-92,-392},{-66,-392},{-66,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(statePoint2.sensorPort, hx.portA_a) annotation (Line(
      points={{-108,-380},{-108,-392},{-66,-392},{-66,-370}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC7.port, statePoint_03.sensorPort) annotation (Line(
      points={{-8,212},{-8,200},{20,200},{20,204}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC6.port, gasCooler_EnergyWell.portB_a) annotation (Line(
      points={{-114,210},{-114,200},{-64,200}},
      color={153,204,0},
      thickness=0.5));
  connect(sensor_T_degC4.port, gasCooler_EnergyWell.portB_b) annotation (Line(
      points={{-68,230},{-68,216},{-64,216}},
      color={0,170,238},
      thickness=0.5));
  connect(sensor_T_degC5.port, liquidSink.port) annotation (Line(
      points={{-26,230},{-26,216},{-22,216}},
      color={0,170,238},
      thickness=0.5));
  connect(HPComp_FI.rotatoryFlange, rotatoryBoundaryWithInputs.rotatoryFlange)
    annotation (Line(
      points={{158,172},{164,172},{164,170},{170,170}},
      color={135,135,135},
      thickness=0.5));
  annotation (
    Diagram(coordinateSystem(
        preserveAspectRatio=false,
        extent={{-300,-400},{280,240}},
        initialScale=0.1)),
    experiment(StopTime=20000, __Dymola_Algorithm="Dassl"),
    __Dymola_experimentSetupOutput(equdistant=false),
    Icon(coordinateSystem(extent={{-300,-400},{280,240}},
        preserveAspectRatio=false,
        initialScale=0.1)),
    Documentation(info="<html>
        <p>
        This CO2-Booster system represents a typical cycle for a CO2-Supermarket refrigeration plant.
        The R744 refrigeration cycle has two evaporators and there are four pressure levels in total.
        In the low temperature cabinet, the refrigerant evaporates at -28 &deg;C and 12 bar.
        In the low pressure compressors, the refrigerant is compressed to the evaporation pressure of the medium temperature cabinets.
        The refrigerant mass flow from both cabinets are mixed and compressed to the condensing pressure.
        After throtteling in the HP-Valve, the liquid refrigerant is separated in a medium pressure receiver and afterwards throttled further down to the evaporation pressures.
        This examples demonstrates the transition from subcritical (normal condensation-) to transcritical operation.
        The temperature of the heat sink (water) is increased and simultaneously, the high pressure is increased.
        </p>
        </html>"),
    uses(
      Modelica(version="3.2.2"),
      TIL(version="3.5.0"),
      TILMedia(version="3.5.0")));
end SupermarketRefrigerationSystem_CO2_20190524;
